@@ -86,7 +86,8 @@ typedef enum
 {
 	EMBED_RELOAD_NORMAL = 1 << 1,
   	EMBED_RELOAD_BYPASSCACHE = 1 << 2,
-  	EMBED_RELOAD_BYPASSPROXY = 1 << 3
+  	EMBED_RELOAD_BYPASSPROXY = 1 << 3,
+	EMBED_RELOAD_FRAME = 1 << 4
 } EmbedReloadFlags;
 
 typedef enum
@@ -171,6 +172,21 @@ typedef enum
 	STATE_IS_SECURE_HIGH
 } EmbedSecurityLevel;
 
+typedef enum
+{
+	STYLESHEET_NONE,  /* no stylesheet */
+	STYLESHEET_BASIC, /* no named stylesheets */
+	STYLESHEET_NAMED  /* Named stylesheet */ 
+} EmbedStyleSheetType;
+                                                                                                                                              
+typedef struct
+{
+	gchar *name;    /* stylesheet name */
+	gpointer sheet; /* opaque pointer to the underlying sheet object */
+	EmbedStyleSheetType type;
+} EmbedStyleSheet;
+
+
 struct GaleonEmbedClass
 {
         GTypeInterface base_iface;
@@ -284,6 +300,7 @@ struct GaleonEmbedClass
 					    gboolean back_history,
 					    gboolean forward_history,
 					    gboolean set_current);
+	gresult   (* shistory_clear)       (GaleonEmbed *embed);
 	gresult   (* scroll)               (GaleonEmbed *embed, 
 		  			    EmbedScrollDirection direction);
 	gresult	  (* fine_scroll)	   (GaleonEmbed *embed, 
@@ -301,9 +318,20 @@ struct GaleonEmbedClass
 	gresult   (* print_preview_navigate)	(GaleonEmbed *embed,
 						 EmbedPrintPreviewNavType navType,
 						 gint pageNum);
-
 	gresult   (* set_charset)          (GaleonEmbed *embed,
 					    const char *charset);
+
+	gresult   (* get_stylesheets)	   (GaleonEmbed *embed,
+					    GList **retSheets);
+	gresult   (* get_selected_stylesheet)   (GaleonEmbed *embed,
+						 EmbedStyleSheet **retSheet);
+	gresult   (* set_stylesheet)	   (GaleonEmbed *embed,
+					    EmbedStyleSheet *sheet);
+	gresult   (* apply_user_stylesheet)  (GaleonEmbed *embed,
+					      const gchar *sheetfile,
+					      EmbedStyleSheet **retSheet);
+	gresult   (* remove_user_stylesheet)   (GaleonEmbed *embed,
+						EmbedStyleSheet *sheet);
 };	
 	
 GType         galeon_embed_get_type             (void);
@@ -420,6 +448,8 @@ gboolean      galeon_embed_shistory_copy	(GaleonEmbed *source,
 						 gboolean forward_history,
 						 gboolean set_current);
 
+gresult       galeon_embed_shistory_clear	(GaleonEmbed *embed);
+
 /* Utils */
 
 gresult       galeon_embed_scroll               (GaleonEmbed *embed, 
@@ -452,6 +482,24 @@ gresult       galeon_embed_print_preview_navigate	(GaleonEmbed *embed,
 							 EmbedPrintPreviewNavType navType,
 							 gint pageNum);
 
+gresult   galeon_embed_get_stylesheets		(GaleonEmbed *embed,
+						 GList **retSheets);
+gresult   galeon_embed_get_selected_stylesheet	(GaleonEmbed *embed,
+						 EmbedStyleSheet **retSheet);
+gresult   galeon_embed_set_stylesheet		(GaleonEmbed *embed,
+						 EmbedStyleSheet *sheet);
+gresult   galeon_embed_apply_user_stylesheet	(GaleonEmbed *embed,
+						 const gchar *sheetfile,
+						 EmbedStyleSheet **retSheet);
+gresult   galeon_embed_remove_user_stylesheet	(GaleonEmbed *embed,
+						 EmbedStyleSheet *sheet);
+
+/* helper functions */
+gboolean  galeon_embed_stylesheet_compare	(EmbedStyleSheet *ess1, EmbedStyleSheet *ess2);
+void	  galeon_embed_stylesheet_free		(EmbedStyleSheet *ess);
+void	  galeon_embed_stylesheet_list_free	(GList *l);
+
+
 #ifdef __cplusplus
 }
 #endif
