@@ -100,6 +100,13 @@ mozilla_proxy_mode_notifier (GConfClient *client,
 			     guint cnxn_id,
 			     GConfEntry *entry,
 			     char *pref);
+
+static void
+mozilla_proxy_ignore_notifier (GConfClient *client,
+			     guint cnxn_id,
+			     GConfEntry *entry,
+			     char *pref);
+
 static void
 mozilla_proxy_autoconfig_notifier (GConfClient *client,
 			           guint cnxn_id,
@@ -112,11 +119,6 @@ mozilla_user_agent_notifier(GConfClient *client,
 			    GConfEntry *entry,
 			    gpointer user_data);
 
-static void 
-mozilla_default_charset_notifier (GConfClient *client,
-				  guint cnxn_id,
-				  GConfEntry *entry,
-				  GaleonEmbedShell *shell);
 static void
 mozilla_socks_version_notifier (GConfClient *client,
 				guint cnxn_id,
@@ -151,6 +153,7 @@ conversion_table [] =
 	{ CONF_RENDERING_UNVISITED_LINKS, STRING_PREF, "browser.anchor_color"},
 	{ CONF_RENDERING_VISITED_LINKS, STRING_PREF, "browser.visited_color"},
 	{ CONF_RENDERING_UNDERLINE_LINKS, BOOL_PREF, "browser.underline_anchors"},
+  	{ CONF_LANGUAGE_DEFAULT_CHARSET, STRING_PREF, "intl.charset.default" },
 	{ CONF_NETWORK_PROXY_AUTO_URL, STRING_PREF, "network.proxy.autoconfig_url"},
 	{ CONF_NETWORK_HTTP_PROXY, STRING_PREF, "network.proxy.http"},
 	{ CONF_NETWORK_FTP_PROXY, STRING_PREF, "network.proxy.ftp"},
@@ -160,27 +163,14 @@ conversion_table [] =
 	{ CONF_NETWORK_FTP_PROXY_PORT, INT_PREF, "network.proxy.ftp_port"},
 	{ CONF_NETWORK_SSL_PROXY_PORT, INT_PREF, "network.proxy.ssl_port"},
 	{ CONF_NETWORK_SOCKS_PROXY_PORT, INT_PREF, "network.proxy.socks_port"},
-	{ CONF_NETWORK_NO_PROXIES_FOR, STRING_PREF, "network.proxy.no_proxies_on"},
 	{ CONF_NETWORK_PROXY_KA, BOOL_PREF, "network.http.proxy.keep-alive"},
 	{ CONF_NETWORK_MEMORY_CACHE, INT_PREF, "browser.cache.memory.capacity"},
 	{ CONF_NETWORK_DISK_CACHE, INT_PREF, "browser.cache.disk.capacity"},
 	{ CONF_NETWORK_CACHE_COMPARE, INT_PREF, "browser.cache.check_doc_frequency"},
 	{ CONF_MOUSE_WHEEL_NOKEY_ACTION, INT_PREF, "mousewheel.withnokey.action"},
-	{ CONF_MOUSE_WHEEL_SHIFT_ACTION, INT_PREF, "mousewheel.withshiftkey.action"},
-	{ CONF_MOUSE_WHEEL_ALT_ACTION, INT_PREF, "mousewheel.withaltkey.action"},
-	{ CONF_MOUSE_WHEEL_CTRL_ACTION, INT_PREF, "mousewheel.withcontrolkey.action"},
-	{ CONF_MOUSE_WHEEL_NOKEY_DEF_STEP, INT_PREF, "mousewheel.withnokey.sysnumlines"},
-	{ CONF_MOUSE_WHEEL_CTRL_DEF_STEP, INT_PREF, "mousewheel.withcontrolkey.sysnumlines"},
-	{ CONF_MOUSE_WHEEL_ALT_DEF_STEP, INT_PREF, "mousewheel.withaltkey.sysnumlines"},
-	{ CONF_MOUSE_WHEEL_SHIFT_DEF_STEP, INT_PREF, "mousewheel.withshiftkey.sysnumlines"},
+	{ CONF_MOUSE_WHEEL_NOKEY_DEF_STEP, BOOL_PREF, "mousewheel.withnokey.sysnumlines"},
 	{ CONF_MOUSE_WHEEL_NOKEY_STEP, INT_PREF, "mousewheel.withnokey.numlines"},
-	{ CONF_MOUSE_WHEEL_CTRL_STEP, INT_PREF, "mousewheel.withcontrolkey.numlines"},
-	{ CONF_MOUSE_WHEEL_ALT_STEP, INT_PREF, "mousewheel.withaltkey.numlines"},
-	{ CONF_MOUSE_WHEEL_SHIFT_STEP, INT_PREF, "mousewheel.withshiftkey.numlines"},
 	{ CONF_MOUSE_WHEEL_STEP_SIZE, INT_PREF, "mousewheel.withnokey.numlines"},
-	{ CONF_MOUSE_WHEEL_CTRL_STEP, INT_PREF, "mousewheel.withcontrolkey.numlines"},
-	{ CONF_MOUSE_WHEEL_ALT_STEP, INT_PREF, "mousewheel.withaltkey.numlines"},
-	{ CONF_MOUSE_WHEEL_SHIFT_STEP, INT_PREF, "mousewheel.withshiftkey.numlines"},
 	{ CONF_PERSISTENT_COOKIE_WARN, BOOL_PREF, "network.cookie.warnAboutCookies"},
 	{ CONF_PERSISTENT_COOKIES_BEHAVIOR, INT_PREF, "network.cookie.cookieBehavior"},
 	{ CONF_PERSISTENT_COOKIE_LIFETIME, BOOL_PREF, "network.cookie.lifetime.enabled"},
@@ -209,8 +199,6 @@ custom_notifiers [] =
 	  (GConfClientNotifyFunc) mozilla_http_version_notifier },
 	{ CONF_FILTERING_ALLOW_POPUPS, 
 	  (GConfClientNotifyFunc) mozilla_allow_popups_notifier },
-	{ CONF_LANGUAGE_DEFAULT_CHARSET, 
-	  (GConfClientNotifyFunc) mozilla_default_charset_notifier },
 	{ CONF_RENDERING_LANGUAGE, 
 	  (GConfClientNotifyFunc) mozilla_language_notifier },
 	{ CONF_LANGUAGE_AUTODETECT_CHARSET, 
@@ -223,6 +211,8 @@ custom_notifiers [] =
 	  (GConfClientNotifyFunc) mozilla_proxy_mode_notifier },
 	{ CONF_NETWORK_PROXY_AUTO_URL,
 	  (GConfClientNotifyFunc) mozilla_proxy_autoconfig_notifier },
+	{ CONF_NETWORK_PROXY_IGNORE_HOSTS,
+	  (GConfClientNotifyFunc) mozilla_proxy_ignore_notifier },
 	{NULL, NULL}
 };
 
@@ -234,9 +224,11 @@ mozilla_font_size_notifier (GConfClient *client,
 {
 	char key[255];
 	
+	if (entry->value == NULL) return;
+
 	sprintf (key, "font.%s", pref);
 
-	mozilla_prefs_set_int (key, gconf_value_get_int(entry->value));
+	mozilla_prefs_set_int (key, eel_gconf_get_integer (entry->key));
 }
 
 static void
@@ -245,10 +237,11 @@ mozilla_proxy_mode_notifier (GConfClient *client,
 		             GConfEntry *entry,
 		             char *pref)
 {
-	const char *mode;
+	char *mode;
 	int mozilla_mode = 0;
 	
-	mode = gconf_value_get_string(entry->value);
+	mode = eel_gconf_get_string (entry->key);
+	if (mode == NULL) return;
 	
 	if (strcmp (mode, "manual") == 0)
 	{
@@ -260,6 +253,43 @@ mozilla_proxy_mode_notifier (GConfClient *client,
 	}
 
 	mozilla_prefs_set_int ("network.proxy.type", mozilla_mode);
+
+	g_free (mode);
+}
+
+static void
+mozilla_proxy_ignore_notifier (GConfClient *client,
+		             guint cnxn_id,
+		             GConfEntry *entry,
+		             char *pref)
+{
+	GSList *hosts, *l;
+	char **strings, *mozilla_ignore_list;
+	int i = 0;
+
+	hosts = eel_gconf_get_string_list (entry->key);
+
+	strings = g_new (gchar*, g_slist_length (hosts) + 1);
+	for (l = hosts; l != NULL; l = l->next)
+	{
+		char *item = (char *) l->data;
+
+		if (item && item[0] != '\0')
+		{
+			strings[i] = item;
+			i++;
+		}
+	}
+	strings[i] = NULL;
+
+	mozilla_ignore_list = g_strjoinv (", ", strings);
+	mozilla_prefs_set_string ("network.proxy.no_proxies_on",
+				  mozilla_ignore_list);
+
+	g_free (mozilla_ignore_list);
+	g_free (strings);
+	g_slist_foreach (hosts, (GFunc) g_free, NULL);
+	g_slist_free (hosts);
 }
 
 static void
@@ -269,10 +299,18 @@ mozilla_font_notifier (GConfClient *client,
 		       char *pref)
 {
 	char key[255];
+	char *name;
+
+	if (entry->value == NULL) return;
 	
 	sprintf (key, "font.name.%s", pref);
 
-	mozilla_prefs_set_string (key, gconf_value_get_string(entry->value));
+	name = eel_gconf_get_string (entry->key);
+	if (name)
+	{
+		mozilla_prefs_set_string (key, name);
+		g_free (name);
+	}
 }
 
 static void
@@ -281,8 +319,15 @@ mozilla_proxy_autoconfig_notifier (GConfClient *client,
 		       		   GConfEntry *entry,
 		       		   char *pref)
 {
-	galeon_embed_shell_load_proxy_autoconf 
-		(embed_shell, gconf_value_get_string(entry->value));
+	char *url;
+
+	url = eel_gconf_get_string (entry->key);
+
+	if (url)
+	{
+		galeon_embed_shell_load_proxy_autoconf (embed_shell, url);
+		g_free (url);
+	}
 }
 
 static void
@@ -437,24 +482,14 @@ generic_mozilla_string_notifier(GConfClient *client,
 				GConfEntry *entry,
 				const char *pref_name)
 {
-	const gchar *value;
+	char *value;
 
-	/* determine type of gconf key, in order of likelyhood */
-	switch (entry->value->type)
+	value = eel_gconf_get_string (entry->key);
+	if (value)
 	{
-		case GCONF_VALUE_STRING:
-			value = gconf_value_get_string(entry->value);
-			if (value)
-			{
-				mozilla_prefs_set_string
-					(pref_name,
-					 gconf_value_get_string(entry->value));
-			}
-			break;
-
-		default:	
-			g_warning("Unsupported variable type");
-	} 
+		mozilla_prefs_set_string (pref_name, value);
+		g_free (value);
+	}
 }
 
 
@@ -468,20 +503,10 @@ generic_mozilla_int_notifier(GConfClient *client,
 			     GConfEntry *entry,
 			     const char *pref_name)
 {
-	/* determine type of gconf key, in order of likelyhood */
-	switch (entry->value->type)
-	{
-		case GCONF_VALUE_INT:	mozilla_prefs_set_int(pref_name,
-						gconf_value_get_int(entry->value));
-					break;
-		case GCONF_VALUE_BOOL:	mozilla_prefs_set_boolean(pref_name,
-						gconf_value_get_bool(entry->value));
-					break;
-		case GCONF_VALUE_STRING:	mozilla_prefs_set_string(pref_name,
-						gconf_value_get_string(entry->value));
-					break;
-		default:	g_warning("Unsupported variable type");
-	}
+	int value;
+
+	value = eel_gconf_get_integer (entry->key);
+	mozilla_prefs_set_int (pref_name, value);
 }
 
 
@@ -495,37 +520,22 @@ generic_mozilla_bool_notifier(GConfClient *client,
 			      GConfEntry *entry,
 			      const char *pref_name)
 {
-	/* determine type of gconf key, in order of likelyhood */
-	switch (entry->value->type)
-	{
-		case GCONF_VALUE_BOOL:	mozilla_prefs_set_boolean(pref_name,
-						gconf_value_get_bool(entry->value));
-					break;
-		case GCONF_VALUE_INT:	mozilla_prefs_set_int(pref_name,
-						gconf_value_get_int(entry->value));
-					break;
-		default:	g_warning("Unsupported variable type");
-	}
-}
+	gboolean value;
 
-static void 
-mozilla_default_charset_notifier(GConfClient *client,
-				 guint cnxn_id,
-				 GConfEntry *entry,
-				 GaleonEmbedShell *shell)
-{
-	/* FIXME */
+	value = eel_gconf_get_boolean (entry->key);
+	mozilla_prefs_set_boolean (pref_name, value);
 }
 
-
 static void
 mozilla_own_colors_notifier(GConfClient *client,
 			    guint cnxn_id,
 			    GConfEntry *entry,
 			    gpointer user_data)
 {
-	mozilla_prefs_set_boolean("browser.display.use_document_colors",
-				       !gconf_value_get_bool(entry->value));
+	gboolean value;
+
+	value = eel_gconf_get_boolean (entry->key);
+	mozilla_prefs_set_boolean ("browser.display.use_document_colors", !value);
 }
 
 static void
@@ -534,8 +544,10 @@ mozilla_own_fonts_notifier(GConfClient *client,
 			   GConfEntry *entry,
 			   gpointer user_data)
 {
-	mozilla_prefs_set_int("browser.display.use_document_fonts",
-				   !gconf_value_get_bool(entry->value));
+	int value;
+
+	value = eel_gconf_get_boolean (entry->key) ? 0 : 1;
+	mozilla_prefs_set_int("browser.display.use_document_fonts", value);
 }
 
 static void
@@ -544,6 +556,7 @@ mozilla_animate_notifier(GConfClient *client,
 			 GConfEntry *entry,
 			 gpointer user_data)
 {
+	int value;
 	static const gchar *type[] =
 	{
 		"normal",
@@ -551,8 +564,10 @@ mozilla_animate_notifier(GConfClient *client,
 		"none"
 	};
 
-	mozilla_prefs_set_string ("image.animation_mode",
-				  type[gconf_value_get_int(entry->value)]);
+        value = eel_gconf_get_integer (entry->key);
+        if (value > 2 || value < 0) value = 0;
+
+	mozilla_prefs_set_string ("image.animation_mode", type[value]);
 }
 
 static void
@@ -689,34 +704,7 @@ mozilla_default_font_notifier(GConfClient *client,
 static void
 mozilla_prefs_set_user_agent ()
 {
-        static gchar *default_user_agent = NULL;
-        gchar *value;
-        gchar *user_agent = NULL;
-        struct utsname name;
-        gchar *system;
-
-        if (!default_user_agent)
-        {
-                if (uname (&name) == 0)
-                {
-                        system = g_strdup_printf ("%s %s",
-                                                  name.sysname, 
-                                                  name.machine);
-                }
-                else
-                {
-                        system = g_strdup ("Unknown");
-                }
-                
-                default_user_agent = g_strdup_printf
-                        ("Mozilla/5.0 (X11; U; %s) Gecko/%d Galeon/" VERSION, 
-                         system,
-                         NS_BUILD_ID/100);
-
-                g_free (system);
-        }
-
-        value = eel_gconf_get_string (CONF_NETWORK_USER_AGENT);
+        gchar *value = eel_gconf_get_string (CONF_NETWORK_USER_AGENT);
         
         /* now, build a valid user agent string */
         if (!value || !strcmp ("", value) 
@@ -725,15 +713,14 @@ mozilla_prefs_set_user_agent ()
                    || !strcmp (_("Default (recommended)"), value)
                    || !strcmp ("Default (recommended)", value))
         {
-                user_agent = g_strdup (default_user_agent);
+		mozilla_prefs_remove ("general.useragent.override");
         }
         else
         {
-                user_agent = g_strdup (value);
+		mozilla_prefs_set_string ("general.useragent.override", value);
         }
 
-	mozilla_prefs_set_string ("general.useragent.override", user_agent);
-	g_free (user_agent);
+	g_free (value);
 }
 
 static void
@@ -742,16 +729,7 @@ mozilla_user_agent_notifier (GConfClient *client,
 			     GConfEntry *entry,
 			     gpointer user_data)
 {
-	switch (entry->value->type)
-	{
-		case GCONF_VALUE_STRING:
-			mozilla_prefs_set_user_agent ();
-			break;
-
-		default:	
-			g_warning ("Unsupported variable type");
-			break;
-	}
+	mozilla_prefs_set_user_agent ();
 }
 
 static void
@@ -761,7 +739,7 @@ mozilla_socks_version_notifier (GConfClient *client,
 				gpointer user_data)
 {
 	int version;
-	version = gconf_value_get_int(entry->value) + 4;
+	version = eel_gconf_get_integer (entry->key) + 4;
 	mozilla_prefs_set_int ("network.proxy.socks_version", 
 			       version);
 }
